pub struct SchemaRegistry { /* private fields */ }Implementations
Sourceimpl SchemaRegistry
impl SchemaRegistry
pub fn new() -> Self
Sourcepub fn clear(&mut self)
pub fn clear(&mut self)
Resets the schema registry to a blank slate without releasing the allocations
Sourcepub fn register(
&mut self,
type_id: WireTypeId,
entry: SchemaEntry,
) -> Result<(), String>
pub fn register( &mut self, type_id: WireTypeId, entry: SchemaEntry, ) -> Result<(), String>
Register a schema under the given wire type ID.
pub fn get(&self, type_id: WireTypeId) -> Option<&SchemaEntry>
pub fn entries(&self) -> impl Iterator<Item = (WireTypeId, &SchemaEntry)>
Sourcepub fn next_type_id(&mut self) -> WireTypeId
pub fn next_type_id(&mut self) -> WireTypeId
Allocate the next wire type ID.
Sourcepub fn sync_next_id(&mut self)
pub fn sync_next_id(&mut self)
Advance next_id past all registered type IDs.
Call this after bulk-inserting schemas (e.g. from a decoded trace) so
that next_type_id won’t collide.